# PySentry - pip-audit Benchmark Report

**Generated:** 2026-02-19 18:13:11
**Duration:** 1m 56.73s
**Total Tests:** 20

## Executive Summary

**Overall Success Rate:** 100.0% (20/20 successful runs)

### Small_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (0.622s) - 14.41x faster than slowest
- **Memory Efficient:** pysentry-osv (18.83 MB) - 4.45x less memory than highest

### Small_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.309s) - 25.79x faster than slowest
- **Memory Efficient:** pysentry-osv (11.19 MB) - 7.71x less memory than highest

### Large_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-osv (1.429s) - 12.66x faster than slowest
- **Memory Efficient:** pysentry-osv (36.08 MB) - 3.13x less memory than highest

### Large_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.880s) - 17.74x faster than slowest
- **Memory Efficient:** pysentry-osv (11.80 MB) - 7.94x less memory than highest

## Test Environment

- **Platform:** Linux-6.11.0-1018-azure-x86_64-with-glibc2.39
- **Python Version:** 3.11.14
- **CPU Cores:** 4
- **Total Memory:** 15.62 GB
- **Available Memory:** 14.60 GB

## Performance Comparison

### Small_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.622s | 1.00x |
| 🥈 pysentry-osv | 0.805s | 1.30x |
|  pysentry-all-sources | 1.746s | 2.81x |
|  pysentry-pypa | 2.000s | 3.22x |
|  pip-audit-default | 8.961s | 14.41x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 18.83 MB | 1.00x |
| 🥈 pysentry-pypi | 19.25 MB | 1.02x |
|  pip-audit-default | 45.57 MB | 2.42x |
|  pysentry-pypa | 67.65 MB | 3.59x |
|  pysentry-all-sources | 83.75 MB | 4.45x |

### Small_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.309s | 1.00x |
| 🥈 pysentry-osv | 0.503s | 1.63x |
|  pysentry-pypa | 1.442s | 4.66x |
|  pysentry-all-sources | 1.575s | 5.09x |
|  pip-audit-default | 7.977s | 25.79x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 11.19 MB | 1.00x |
| 🥈 pysentry-pypi | 12.47 MB | 1.11x |
|  pip-audit-default | 44.33 MB | 3.96x |
|  pysentry-pypa | 59.66 MB | 5.33x |
|  pysentry-all-sources | 86.21 MB | 7.71x |

### Large_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 1.429s | 1.00x |
| 🥈 pysentry-pypi | 1.501s | 1.05x |
|  pysentry-all-sources | 2.231s | 1.56x |
|  pysentry-pypa | 2.247s | 1.57x |
|  pip-audit-default | 18.096s | 12.66x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 36.08 MB | 1.00x |
| 🥈 pysentry-pypi | 37.80 MB | 1.05x |
|  pip-audit-default | 48.04 MB | 1.33x |
|  pysentry-pypa | 84.86 MB | 2.35x |
|  pysentry-all-sources | 112.91 MB | 3.13x |

### Large_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.880s | 1.00x |
| 🥈 pysentry-osv | 1.163s | 1.32x |
|  pysentry-all-sources | 1.937s | 2.20x |
|  pysentry-pypa | 1.938s | 2.20x |
|  pip-audit-default | 15.617s | 17.74x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 11.80 MB | 1.00x |
| 🥈 pysentry-pypi | 13.18 MB | 1.12x |
|  pip-audit-default | 47.57 MB | 4.03x |
|  pysentry-pypa | 62.70 MB | 5.31x |
|  pysentry-all-sources | 93.72 MB | 7.94x |

## Detailed Analysis

### Pysentry Performance

- **Execution Time:** Avg: 1.396s, Min: 0.309s, Max: 2.247s

- **Memory Usage:** Avg: 50.75 MB, Min: 11.19 MB, Max: 112.91 MB

- **Success Rate:** 100.0% (16/16)

### Pip-Audit Performance

- **Execution Time:** Avg: 12.663s, Min: 7.977s, Max: 18.096s

- **Memory Usage:** Avg: 46.38 MB, Min: 44.33 MB, Max: 48.04 MB

- **Success Rate:** 100.0% (4/4)